##############################################
#
# cell
# Module | Main component of a Data Visualization Model like Articles or FileCards.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
#############################################

from semantyk.core.model import Model

class Cell(Model):
    pass