##############################################
#
# venn_diagram
# Module | Diagram that displays all possible logical objects of type Relation between a finite collection of different objects of type Resource.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
#############################################

from semantyk.data_visualization_models.graph.graph import Graph

class VennDiagram(Graph):
    pass