##############################################
#
# dvm_extract_cell
# Module | Data Visualization Model Extract Cell Module.
#
# Daniel Bakas Amuchastegui
# February, 2020
# 
# Copyright © Semantyk 2020. All rights reserved.
#############################################

from semantyk.data_visualization_models.cell.cell import Cell

class DVMExtractCell(Cell):
    pass