##############################################
#
# Store
# Package | Intelligent System For Product Selection Package.
#
# Daniel Bakas Amuchastegui
# March 16, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
#############################################