##############################################
#
# namespace
# Package | Namespace Package.
#
# Daniel Bakas Amuchastegui
# Nay 10, 2020
# 
# Copyright © Semantyk 2020. All rights reserved.
#############################################

from . import namespace

from .namespace import *