##############################################
#
# article
# Module | Written compositions describing the content of a Resouce, through the use of Cells.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
#############################################

from semantyk.core.model import Model

class Article(Model):
    pass